@@ -1,6 +1,6 @@
 package Brannigan::Tree;
 BEGIN {
-  $Brannigan::Tree::VERSION = '0.7';
+  $Brannigan::Tree::VERSION = '0.8';
 }
 
 use strict;
@@ -13,7 +13,7 @@ Brannigan::Tree - A Brannigan validation/parsing scheme tree, possibly built fro
 
 =head1 VERSION
 
-version 0.7
+version 0.8
 
 =head1 DESCRIPTION
 
@@ -309,6 +309,9 @@ sub _validate_scalar {
 		if ($v eq 'validate' && ref $validations->{$v} eq 'CODE') {
 			# this is an "inline" validation method, invoke it
 			push(@rejects, $v) unless $validations->{$v}->($value, @data);
+		} elsif (exists $self->{_custom_validations} && exists $self->{_custom_validations}->{$v} && ref $self->{_custom_validations}->{$v} eq 'CODE') {
+			# this is a cross-scheme custom validation method
+			push(@rejects, $v.'('.join(', ', @data).')') unless $self->{_custom_validations}->{$v}->($value, @data);
 		} else {
 			# we're using a built-in validation method
 			push(@rejects, $v.'('.join(', ', @data).')') unless Brannigan::Validations->$v($value, @data);
